@@ -21,9 +21,13 @@ private Q_SLOTS:
     void testModifiers();
     void testModifierless();
     void testModifierOnly();
+    void testModifierOnlyMultiple();
+    void testModifierOnlyMultipleInterrupt();
     void testModifierOnlyDisabled();
     void testMultiKeyAllowed();
     void testKeyNonLetterNoModifier();
+    void testPattern_data();
+    void testPattern();
 
 private:
     QWindow *m_window;
